class Admin::DiplomasController < OrbitMemberController
  layout "member_plugin"
   include Admin::PersonalDiplomasHelper

  before_action :set_diploma, only: [:show, :edit , :update, :destroy]
  before_action :set_plugin
  before_action :get_settings,:only => [:new, :edit, :setting]

  before_action :need_access_right
  before_action :allow_admin_only, :only => [:index, :setting]

  def index
    @diplomas = Diploma.sort_date.page(params[:page]).per(10)
  end

  def new
    @member = MemberProfile.find_by(:uid=>params['uid'].to_s) rescue nil
    @diploma = Diploma.new

    if params[:desktop]
      render :layout => false
    end
  end

  def create

    if !diploma_params['member_profile_id'].blank?

      @member = MemberProfile.find(diploma_params['member_profile_id']) rescue nil
      @diploma = Diploma.new(diploma_params)
      @diploma.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      else
        redirect_to params['referer_url']
      end

    elsif !params[:author_members].blank?

      params[:author_members].each do |author_member|

        diploma_params['member_profile_id'] = author_member
        @diploma = Diploma.new(diploma_params)
        @diploma.save

        if params[:desktop] == "true"
          render json: {"data" => get_paper_list}.to_json
        end

      end

      redirect_to params['referer_url']

    else

      diploma_params['member_profile_id'] = User.find(current_user.id).member_profile_id

      @diploma = Diploma.new(diploma_params)
      @diploma.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      end

      redirect_to params['referer_url']

    end
    
  end

  def edit
    @member = @diploma.member_profile rescue nil
    if params[:desktop]
      render :layout =>false
    end
  end

  def update
    @member = @diploma.member_profile rescue nil
    @diploma.update_attributes(diploma_params)
    @diploma.save
    if params[:desktop] == "true"
      render json: {"data" => get_paper_list}.to_json
    else
      redirect_to params['referer_url']
    end
  end

  def destroy
    @diploma.destroy
      respond_to do |format|
        format.html { redirect_to(admin_diplomas_url) }
        format.js
        format.json {render json: {"success" => true}}
      end
  end

  def excel_format
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="diplomas_format.xlsx"'
      }
    end
  end

  def import_from_excel
    workbook = RubyXL::Parser.parse(params["import_file"].tempfile)
    sheet = workbook[0]
    if sheet.count <= 503
      sheet.each_with_index do |row, i|
        next if i < 3
        user = User.where(:user_name => row.cells[0].value).first rescue nil
        if !user.nil?
          mp = user.member_profile
          import_this_diploma(row,mp)
        end
      end
      redirect_to admin_diplomas_url
    else
      redirect_to admin_diplomas_url(:error => "1")
    end
  end

  def toggle_hide
    if params[:ids]
      @diplomas = Diploma.any_in(_id: params[:ids])

      @diplomas.each do |diploma|
        diploma.is_hidden = params[:disable]
        diploma.save
      end
    end

    render json: {"success"=>true}
  end

  def setting
  end

  def frontend_setting
    @member = MemberProfile.find_by(:uid=>params['uid'].to_s) rescue nil
    @intro = DiplomaIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? DiplomaIntro.new({:member_profile_id=>@member.id}) : @intro
  end

  def update_frontend_setting
    @member = MemberProfile.find(intro_params['member_profile_id']) rescue nil
    @intro = DiplomaIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? DiplomaIntro.new({:member_profile_id=>@member.id}) : @intro
    @intro.update_attributes(intro_params)
    @intro.save
    redirect_to URI.encode('/admin/members/'+@member.to_param+'/Diploma')
  end

  def get_settings
    @paper_types = ConferencePaperType.all
    @paper_levels = ConferencePaperLevel.all
    @author_types = ConferenceAuthorType.all
  end

  def set_plugin
    @plugin = OrbitApp::Plugin::Registration.all.select{|plugin| plugin.app_name.eql? 'Diploma'}.first
  end

  private

   def set_diploma
    path = request.path.split('/')
    if path.last.include? '-'
      uid = path[-1].split("-").last
      uid = uid.split("?").first
    else
      uid = path[-2].split("-").last
      uid = uid.split("?").first
    end
     @diploma = Diploma.find_by(:uid => uid) rescue Diploma.find(params[:id])
  end

  def diploma_params
    params.require(:diploma).permit! rescue nil
  end

  def intro_params
    params.require(:diploma_intro).permit! rescue nil
  end
end