class Diploma
  include Mongoid::Document
  include Mongoid::Timestamps
  include OrbitModel::Status
  include Slug

  field :school_name, localize: true
  field :country, localize: true
  field :department, localize: true
  field :degree, localize: true
  
  field :language
  field :keywords
  field :start_date , :type => Date
  field :end_date , :type => Date
  field :url
  field :note
  field :rss2_id
  field :create_user_id, :type => BSON::ObjectId
  field :update_user_id, :type => BSON::ObjectId

  belongs_to :member_profile

  # paginates_per 10

  before_validation :add_http

  index({end_date: -1, start_date: -1, _id: -1}, { unique: false, background: false })
  scope :sort_date, ->{ order_by(:end_date => "desc", :start_date => "desc", :id => "desc") }
  scope :sort_for_frontend, ->{ where(:is_hidden=>false).order_by(:end_date => "desc", :start_date => "desc", :id => "desc") }

  def duration
    if !self.start_date.nil? or !self.end_date.nil?
      (self.start_date.strftime('%Y.%m') rescue "")+' ~ '+(self.end_date.strftime('%Y.%m') rescue I18n.t('personal_diploma.up_to_today'))
    else
      ""
    end
  end

  def slug_title
    [self.school_name,self.department,self.degree].join(' ')
  end

  def self.get_plugin_datas_to_member(datas)
    page = Page.where(:module => "personal_diploma").first rescue nil
    
    if !page.nil? && !page.custom_array_field.blank?
      fields_to_show = page.custom_array_field
    else
      fields_to_show = [
        "country",
        "school_name",
        "department",
        "degree",
        "duration"
      ]
    end
     fields_to_remove = []

      pd_title = []

      fields_to_show.each do |t|
        if (self.fields[t].type.to_s == "String" || self.fields[t].type.to_s == "Object" rescue false)
          fields_to_remove << t if (datas.where(t.to_sym.ne => nil, t.to_sym.ne => "").count == 0 rescue false)
        elsif t == "duration"
          fields_to_remove << t if (datas.where(:start_date.ne => nil).count == 0 rescue false)
        else
          fields_to_remove << t if (datas.where(t.to_sym.ne => nil).count == 0 rescue false)
        end
        pd_title <<  {
            "plugin_data_title" => I18n.t("personal_diploma.#{t}")
          } if !fields_to_remove.include?(t)
      end

      fields_to_show = fields_to_show - fields_to_remove

    plugin_datas = datas.sort_for_frontend.collect do |p|
      
      pd_data = []
      fields_to_show.collect do |t|
        if t == "school_name"
          link = OrbitHelper.url_to_plugin_show(p.to_param,'personal_diploma')
          url_to_plugin_show_blank = OrbitHelper.instance_variable_get(:@url_to_plugin_show_blank)
          tmp_title = p.school_name
          pd_data << { "data_title" => (url_to_plugin_show_blank ? tmp_title : "<a title=\"#{tmp_title}\" href=\"#{link}\" target=\"_blank\">#{tmp_title}</a>") }
        elsif t == "duration"
          if !p.send('start_date').nil? or !p.send('end_date').nil?
           date = (p.send('start_date').strftime('%Y.%m') rescue "")+' ~ '+(p.send('end_date').strftime('%Y.%m') rescue I18n.t('personal_diploma.up_to_today'))
          else
            date = ""
          end
          pd_data << { "data_title" => date }
        else
          pd_data << { "data_title" => p.send(t) }
        end
      end

      {
        "honor_type"=>"",
        "pd_datas" => pd_data
      }

    end

    return [pd_title,plugin_datas]

  end

  def get_plugin_data(fields_to_show)
    plugin_datas = []
    fields_to_show.each do |field|
      plugin_data = self.get_plugin_field_data(field) rescue nil
      next if plugin_data.blank? or plugin_data['value'].blank?
      plugin_datas << plugin_data
    end
    plugin_datas
  end

  def get_plugin_field_data(field)
    case field
    when "language"
       value = I18n.t(self.language) rescue ""
    else
      value = self.send(field) rescue ""
    end

    value = (value =~ /\A#{URI::regexp(['http', 'https'])}\z/) ? "<a href='#{value}' target='blank'>#{value}</a>" : value
    
    {
      "key"=>field,
      "title_class"=>"diploma-#{field.gsub('_','-')}-field",
      "value_class"=>"diploma-#{field.gsub('_','-')}-value",
      "title"=>I18n.t('personal_diploma.'+field),
      "value"=>value
    }
  end

  protected

  def add_http
    unless self.url.blank? || self.url[/^http:\/\//] || self.url[/^https:\/\//]
      self.url = 'http://' + self.url
    end
  end
  
end